pub fn default_db_address() -> &'static strExpand description
The production database postgresql address, from the runtime crate::config configuration
pub fn default_db_address() -> &'static strThe production database postgresql address, from the runtime crate::config configuration