pub fn test_db_address() -> &'static strExpand description
The test database postgresql address, from the runtime crate::config configuration
pub fn test_db_address() -> &'static strThe test database postgresql address, from the runtime crate::config configuration